#!/bin/sh
#----------------------------------------------------------------------------
# /var/install/config.d/talk-update.sh - update or generate new talk configuration
#
# Copyright (c) 2002-2012 The Eisfair Team, team(at)eisfair(dot)org
#
# Creation:     2002-11-17  jed
# Last Update:  $Id: talk-update.sh 31573 2012-09-02 09:14:22Z jed $
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#----------------------------------------------------------------------------

# include eislib
. /var/install/include/eislib

#------------------------------------------------------------------------------
# return string of spaces
# $1  - name of variable
# $2  - length of string - length of variable ($1)
# ret - string of spaces
#------------------------------------------------------------------------------
spaces ()
{
    varname=$1
    varlen=${#varname}
    explen=$2
    if [ "$explen" = "" ]
    then
        # empty string
        explen=$varname
        varlen=0
    fi

    if [ $explen -gt $varlen ]
    then
        # string should be extended
        strlen=`expr $explen - $varlen`

        # fixed spaces string - 60 character long (fast method)
        spacestr="                                                            "
        echo "${spacestr:0:$strlen}"
    fi
}

#------------------------------------------------------------------------------
# rename variables
#------------------------------------------------------------------------------
rename_variables ()
{
    renamed=0
    mecho "renaming parameter(s) ..."
    
    # v1.1.2
#   if [ ! -z "`grep ^SMTP_SMART_HOST $source_conf`" ]
#   then
#       echo "- SMTP_SMART_HOST -> SMTP_SMARTHOST_1_HOST"
#       SMTP_SMARTHOST_1_HOST="$SMTP_SMART_HOST"
#       renamed=1
#   fi    
    
    if [ $renamed -eq 1 ]
    then
        mecho -info "... read documentation for renamed parameter(s)!"
        anykey
    fi    
}

#------------------------------------------------------------------------------
# modify variables
#------------------------------------------------------------------------------
modify_variables ()
{
    modified=0
    mecho "modifying parameter(s) ..."
    
#   if [ "$FETCHMAIL_LIMIT" = "" ]
#   then
#       echo "- FETCHMAIL_LIMIT, '' -> will now be interpreted as 4096000 bytes!"
#       modified=1
#   fi

    if [ $modified -eq 1 ]
    then
        mecho -info "... read documentation for modified parameter(s)!"
        anykey
    fi
}

#------------------------------------------------------------------------------
# add variables
#------------------------------------------------------------------------------
add_variables ()
{
    added=0
    mecho "adding new parameter(s) ..."

#   # v1.0.5
#   if [ -z "`grep ^ANTIVIRUS_ENABLE_ICHECKD $source_conf`" ]
#   then
#       echo "- ANTIVIRUS_ENABLE_ICHECKD='yes'"
#       ANTIVIRUS_ENABLE_ICHECKD='yes'
#       added=1
#   fi    

    if [ $added -eq 1 ]
    then
        mecho -info "... read documentation for new parameter(s)!"
        anykey
    fi
}

#------------------------------------------------------------------------------
# delete variables
#------------------------------------------------------------------------------
delete_variables ()
{
    deleted=0
    mecho "deleting old parameters ..."

    # v1.1.2
#   for varname in "EXISCAN_AV_CLAMAV_HOST EXISCAN_AV_CLAMAV_PORT"
#   do
#       if [ ! -z "`grep \"^$varname\" $source_conf`" ]
#       then
#           echo "- $varname"
#           deleted=1
#       fi
#   done

    if [ $deleted -eq 1 ]
    then
        anykey
    fi
}

#------------------------------------------------------------------------------
# create new configuration
#------------------------------------------------------------------------------
create_config ()
{
    mecho "updating/creating configuration ..."

    {
        echo '#------------------------------------------------------------------------------'
        echo '# /etc/config.d/talk - configuration for talk service on EIS/FAIR'
        echo '#'
        echo '# Copyright (c) 2001-2002 Frank Meyer <frank@eisfair.org>'
        echo '#'
        echo '# Creation:     17.11.2002  jed'
        echo "# Last Updated: `date '+%d.%m.%Y'`  jed"
        echo '#'
        echo '# This program is free software; you can redistribute it and/or modify'
        echo '# it under the terms of the GNU General Public License as published by'
        echo '# the Free Software Foundation; either version 2 of the License, or'
        echo '# (at your option) any later version.'
        echo '#------------------------------------------------------------------------------'
        echo
        echo '#------------------------------------------------------------------------------'
        echo '# general settings'
        echo '#------------------------------------------------------------------------------'
        echo
        echo "START_TALK='$START_TALK'`spaces \"$START_TALK\" 25` # start talk: yes or no"
        echo
        echo "TALK_TRUSTED_NETS_N='$TALK_TRUSTED_NETS_N'`spaces \"$TALK_TRUSTED_NETS_N\" 16` # number of trusted nets or hosts"
        if [ $TALK_TRUSTED_NETS_N -eq 0 ]
        then
            imax=1
        else
            imax=$TALK_TRUSTED_NETS_N
        fi

        idx=1
        while [ $idx -le $imax ]
        do
            eval trusted_nets='$TALK_TRUSTED_NETS_'$idx

            echo "TALK_TRUSTED_NETS_"$idx"='$trusted_nets'`spaces \"$trusted_nets\" 16` # $idx. net or host"

            idx=`expr $idx + 1`
        done

        echo
        echo '#------------------------------------------------------------------------------'
        echo '# ytalk settings'
        echo '#------------------------------------------------------------------------------'
        echo
        echo "TALK_SCROLLING='$TALK_SCROLLING'`spaces \"$TALK_SCROLLING\" 9` # scroll user window when reaching bottom"
        echo "TALK_WORDWRAP='$TALK_WORDWRAP'`spaces \"$TALK_WORDWRAP\" 10` # word-wrap at end of line"
        echo "TALK_AUTO_INVITE='$TALK_AUTO_INVITE'`spaces \"$TALK_AUTO_INVITE\" 7` # automatically accept conections without prompting"
        echo "TALK_RERING='$TALK_RERING'`spaces \"$TALK_RERING\" 12` # rering user who does not respond within 30s"
        echo "TALK_RERING_PROMPT='$TALK_RERING_PROMPT'`spaces \"$TALK_RERING_PROMPT\" 5` # ask for confirmation before reringing"
        echo
        echo '#------------------------------------------------------------------------------'
        echo '# end'
        echo '#------------------------------------------------------------------------------'
    } > $generate_conf

    anykey
}

#==============================================================================
# main
#==============================================================================

#testroot=/soft/jedtalk
 testroot=''

talkfile=$testroot/etc/config.d/talk
installfile=$testroot/var/run/talk.install

# setting defaults
source_conf=$installfile
generate_conf=$talkfile

goflag=0

case "$1"
in
    update)
        goflag=1
        ;;
    test)
        source_conf=$talkfile.new

        generate_conf=$testroot/etc/config.d/mk_talk.test
        goflag=1
        ;;
    *)
        mecho
        mecho "Use one of the following options:"
        mecho
        mecho "  talk-update.sh [test]   - the file $generate_conf.new will be read and a test configuration"
        mecho "                            will be written to the file $testroot/etc/config.d/mk_talk.test."
        mecho
        mecho "  talk-update.sh [update] - the file $generate_conf.import will be read, the configuration will"
        mecho "                            be checked and an updated mail configuration file will be written."
        mecho
        goflag=0
esac

if [ $goflag -eq 1 ]
then
    if [ -f $source_conf ]
    then
        # previous configuration file exists
        mecho -info "configuration file found ..."
        . $source_conf

        rename_variables
        modify_variables
        add_variables
        delete_variables

        create_config

        #backup is done in talk-edit script
        #mv $source_conf $talkfile.backup
    else    
        mecho -error "no configuration $source_conf found - exiting."
    fi    
fi    

#==============================================================================
# end
#==============================================================================
